``eradiate.kernel``
===================

.. automodule:: eradiate.kernel

.. button-link:: https://mitsuba.readthedocs.io
   :color: primary
   :expand:

   :octicon:`link-external` Go to Mitsuba 3 docs

Mitsuba scene templating
------------------------

.. autosummary::
   :toctree: generated/autosummary/

   InitParameter
   KernelDictTemplate
   UpdateParameter
   TypeIdLookupStrategy
   UpdateMapTemplate

Mitsuba scene traversal and rendering
-------------------------------------

.. autosummary::
   :toctree: generated/autosummary/

   MitsubaObjectWrapper
   mi_traverse
   mi_render

Other helpers
-------------

.. autosummary::
   :toctree: generated/autosummary/

   bitmap_to_dataarray
   bitmap_to_dataset
   eval_bsdf
   install_logging
   map_cube
   map_unit_cube
   read_binary_grid3d
   write_binary_grid3d
